package routers

import (
	"spaceofcheng/services/controllers"
	"spaceofcheng/services/controllers/goods"
	"spaceofcheng/services/controllers/message"
	"spaceofcheng/services/controllers/user"

	"github.com/astaxie/beego"
)

func getCommonRoutes() beego.LinkNamespace {
	prefix := beego.AppConfig.String("api::common")

	return beego.NSNamespace(prefix,
		beego.NSRouter("/goodstype", &goods.GoodsController{}, "get:GetGoodsType"),
		beego.NSRouter("/goodstype/:typeid", &goods.GoodsController{}, "get:GetGoodsTypeByID"),
		beego.NSRouter("/goodstype", &goods.GoodsController{}, "post:SaveGoodsType"),
		beego.NSRouter("/goodstype", &goods.GoodsController{}, "put:SaveGoodsType"),
		beego.NSRouter("/goodstype/:typeid", &goods.GoodsController{}, "delete:DelGoodsType"),

		beego.NSRouter("/goodspec", &goods.GoodsController{}, "get:GetGoodsSpec"),
		beego.NSRouter("/goodspec/:specid", &goods.GoodsController{}, "get:GetGoodsSpecByID"),
		beego.NSRouter("/goodspec", &goods.GoodsController{}, "post:SaveGoodsSpec"),
		beego.NSRouter("/goodspec", &goods.GoodsController{}, "put:SaveGoodsSpec"),
		beego.NSRouter("/goodspec/:specid", &goods.GoodsController{}, "delete:DelGoodsSpec"),

		beego.NSRouter("/user", &user.UserController{}, "get:GetUserList"),
		beego.NSRouter("/user/:userid", &user.UserController{}, "get:GetUserByID"),

		beego.NSRouter("/pwd/reset", &user.UserController{}, "put:ResetPassword"),
		beego.NSRouter("/pwd/update", &user.UserController{}, "put:UpdatePassword"),

		beego.NSRouter("/location", &message.MessageController{}, "get:GetLocations"),
		beego.NSRouter("/location/:locationid", &message.MessageController{}, "get:GetLocationById"),
		beego.NSRouter("/location", &message.MessageController{}, "post:SaveLocation"),
		beego.NSRouter("/location", &message.MessageController{}, "put:SaveLocation"),
		beego.NSRouter("/location/:locationid", &message.MessageController{}, "delete:DelLocation"),

		beego.NSRouter("/cmsinfo", &message.MessageController{}, "get:GetCmsInfoList"),
		beego.NSRouter("/cmsinfo/:infoid", &message.MessageController{}, "get:GetCmsInfoByID"),
		beego.NSRouter("/cmsinfo", &message.MessageController{}, "post:SaveCmsInfo"),
		beego.NSRouter("/cmsinfo", &message.MessageController{}, "put:SaveCmsInfo"),
		beego.NSRouter("/cmsinfo/:infoid", &message.MessageController{}, "delete:DelCmsInfo"),

		beego.NSRouter("/cmsimg", &message.MessageController{}, "get:GetImgList"),
		beego.NSRouter("/cmsimg/:imgid", &message.MessageController{}, "get:GetImgByID"),
		beego.NSRouter("/cmsimg", &message.MessageController{}, "post:SaveImage"),
		beego.NSRouter("/cmsimg", &message.MessageController{}, "put:SaveImage"),
		beego.NSRouter("/cmsimg/:imgid", &message.MessageController{}, "delete:DelImg"),

		beego.NSRouter("/news", &message.MessageController{}, "get:GetNews"),
		beego.NSRouter("/news/:newsid", &message.MessageController{}, "get:GetNewsByID"),
		beego.NSRouter("/news", &message.MessageController{}, "post:SaveNews"),
		beego.NSRouter("/news", &message.MessageController{}, "put:SaveNews"),
		beego.NSRouter("/news/:newsid", &message.MessageController{}, "delete:DelNews"),

		beego.NSRouter("/cmscase", &message.MessageController{}, "get:GetCmsCase"),
		beego.NSRouter("/cmscase/:cmscaseid", &message.MessageController{}, "get:GetCmsCaseByID"),
		beego.NSRouter("/cmscase", &message.MessageController{}, "post:SaveCmsCase"),
		beego.NSRouter("/cmscase", &message.MessageController{}, "put:SaveCmsCase"),
		beego.NSRouter("/cmscase/:cmscaseid", &message.MessageController{}, "delete:DelCmsCase"),

		beego.NSRouter("/caseuser", &message.MessageController{}, "get:GetCaseUserByCase"),
		beego.NSRouter("/caseuserbytype", &message.MessageController{}, "get:GetCaseUserByType"),
		beego.NSRouter("/caseuser/:userid", &message.MessageController{}, "get:GetCaseUserByID"),
		beego.NSRouter("/caseuser", &message.MessageController{}, "post:SaveCaseUser"),
		beego.NSRouter("/caseuser", &message.MessageController{}, "put:SaveCaseUser"),
		beego.NSRouter("/caseuser/:userid", &message.MessageController{}, "delete:DelCaseUser"),

		beego.NSRouter("/file", &controllers.BaseController{}, "post:FileUpload"),
	)
}
